#!/bin/sh

PATH=/sbin

INTERFAZ_EXT=eth0
DIR_IP=10.1.1.10/32
RED_LOCAL=10.1.1.0/24
#
#
INTERFAZ_INT=eth1
REDINTERNA=192.168.20.0/24
IP_INTERNA=192.168.20.1/32

PUERTOS_PER=1024:
UNIVERSO=0.0.0.0/0
DNS1=192.168.20.1/32

#
# Limpiamos las reglas actuales
#
iptables -F
iptables -F -t nat

# Quitamos cadenas definidas por usuarios
iptables -X
#----------------------------------------
# Establecer la poltica por defecto
# Denegar entrada
# Denegar el traspaso
# Denegar salida
#-----------------------------------------
iptables -P INPUT DROP
iptables -P FORWARD DROP
iptables -P OUTPUT DROP

# permitimos el "loopback"
iptables -A INPUT -i lo -j ACCEPT 
iptables -A OUTPUT -o lo -j ACCEPT 

#############################################
# Servicios internos
#############################################

# DNS (53) para la red interna
iptables -A INPUT -p UDP -i $INTERFAZ_INT -s $RED_INTERNA --sport $PUERTOS_PER \
                  -d $IP_INTERNA --dport 53 -j ACCEPT
iptables -A OUTPUT -p UDP -o $INTERFAZ_INT -s $IP_INTERNA --sport 53 \
                   -d $RED_INTERNA  --dport $PUERTOS_PER -j ACCEPT

#############################################
# Servicios externos 
#############################################

# Permitimos la entrada a clientes de SSH  (22)
# solo de la red local
iptables -A INPUT -p TCP -m state --state NEW,ESTABLISHED \
                  -i $INTERFAZ_EXT -s $RED_LOCAL --sport $PUERTOS_PER \
                  -d $DIR_IP --dport 22 -j ACCEPT
iptables -A OUTPUT -p TCP -m state --state ESTABLISHED,RELATED \
                   -o $INTERFAZ_EXT -s $DIR_IP --sport 22 \
                   -d $RED_LOCAL  --dport $PUERTOS_PER -j ACCEPT

# DNS (53) para el cortafuegos 
iptables -A INPUT -p UDP -i $INTERFAZ_EXT -s $UNIVERSO --sport 53 \
                  -d $DIR_IP --dport $PUERTOS_PER -j ACCEPT
iptables -A OUTPUT -p UDP -o $INTERFAZ_EXT -s $DIR_IP --sport $PUERTOS_PER \
                   -d $UNIVERSO  --dport 53 -j ACCEPT

#############################################
# Servicios a la red interna
#############################################

# Permitimos la entrada al WEB (80)
iptables -A FORWARD -p TCP -m state --state NEW,ESTABLISHED \
                  -i $INTERFAZ_INT -o $INTERFAZ_EXT \
                  -s $RED_INTERNA  --sport $PUERTOS_PER \
                  -d $UNIVERSO --dport 80 -j ACCEPT
iptables -A FORWARD -p TCP -m state --state ESTABLISHED,RELATED \
                    -i $INTERFAZ_EXT -o $INTERFAZ_INT \
                    -s $UNIVERSO --sport 80 \
                    -d $DIR_IP --dport $PUERTOS_PER -j ACCEPT

# Permitimos la entrada al WEB seguro (443)
iptables -A FORWARD -p TCP -m state --state NEW,ESTABLISHED \
                  -i $INTERFAZ_INT -o $INTERFAZ_EXT \
                  -s $RED_INTERNA  --sport $PUERTOS_PER \
                  -d $UNIVERSO --dport 443 -j ACCEPT
iptables -A FORWARD -p TCP -m state --state ESTABLISHED,RELATED \
                    -i $INTERFAZ_EXT -o $INTERFAZ_INT \
                    -s $UNIVERSO --sport 443 \
                    -d $DIR_IP --dport $PUERTOS_PER -j ACCEPT

# Permitimos la entrada a clientes de SSH  (22)
# solo de la red interna
iptables -A FORWARD -p TCP -m state --state NEW,ESTABLISHED \
                  -i $INTERFAZ_INT -o $INTERFAZ_EXT \
                  -s $RED_INTERNA  --sport $PUERTOS_PER \
                  -d $UNIVERSO --dport 22 -j ACCEPT
iptables -A FORWARD -p TCP -m state --state ESTABLISHED,RELATED \
                    -i $INTERFAZ_EXT -o $INTERFAZ_INT \
                    -s $UNIVERSO --sport 22 \
                    -d $DIR_IP --dport $PUERTOS_PER -j ACCEPT

# Todo el trfico interno es enmascarado externamente
#
iptables -A POSTROUTING -t nat -o $INTERFAZ_EXT -j MASQUERADE

#
# Qu ms podramos hacer:
#
# registrar cualquier conexin denegada
# filtrar otras redes (como en el libro)
# filtrar icmp (para evitar el ataque de pings)
# filtar por MAC
# QoS (Calidad de Servicio)
